# delfin : SODA Infrastructure Manager Project
[![Build Status](https://travis-ci.com/sodafoundation/delfin.svg?branch=master)](https://travis-ci.com/sodafoundation/delfin)
[![codecov.io](https://codecov.io/github/sodafoundation/delfin/coverage.svg?branch=master)](https://codecov.io/github/sodafoundation/delfin?branch=master)
[![Releases](https://img.shields.io/github/release/sodafoundation/delfin/all.svg?style=flat-square)](https://github.com/sodafoundation/delfin/releases)
[![LICENSE](https://img.shields.io/github/license/sodafoundation/delfin.svg?style=flat-square)](https://github.com/sodafoundation/delfin/blob/master/LICENSE)

<img src="https://sodafoundation.io/wp-content/uploads/2020/01/SODA_logo_outline_color_800x800.png" width="200" height="200">

## Introduction

delfin (Dolphin in spanish!) , the SODA Infrastructure Manager project is an an open source project to provide unified, intelligent and scalable resource management, alert and performance monitoring. It will cover the resource management of all the storage backends & other infrastructures under SODA deployment. It will also provide the alert management and metric data(performance/health) for monitoring and further analysis. It will provide a scalable framework where more and more backends as well as client exporters can be added. This will enable to add more storage and infrastructure backends and also support different management clients for monitoring and health prediction.

It provides unified APIs to access, export and connect with clients as well as a set of interfaces for various driver addition.

This is one of the SODA Core Projects and is maintained by SODA Foundation directly.

## Documentation

[https://docs.sodafoundation.io](https://docs.sodafoundation.io/)

## Quick Start - To Use/Experience

[https://docs.sodafoundation.io](https://docs.sodafoundation.io/)

## Quick Start - To Develop

[https://docs.sodafoundation.io](https://docs.sodafoundation.io/)

## Latest Releases

[https://github.com/sodafoundation/delfin/releases](https://github.com/sodafoundation/delfin/releases)

## Support and Issues

[https://github.com/sodafoundation/delfin/issues](https://github.com/sodafoundation/delfin/issues)

## Project Community

[https://sodafoundation.io/slack/](https://sodafoundation.io/slack/)

## How to contribute to this project?

Join [https://sodafoundation.io/slack/](https://sodafoundation.io/slack/) and share your interest in the ‘general’ channel

Checkout [https://github.com/sodafoundation/delfin/issues](https://github.com/sodafoundation/delfin/issues) labelled with ‘good first issue’ or ‘help needed’ or ‘help wanted’ or ‘StartMyContribution’ or ‘SMC’

## Project Roadmap

We want to build a unified intelligent and scalable infrastructure management framework for resource management (config, add, remove, update), alert management and performance metrics management.
  
[https://docs.sodafoundation.io](https://docs.sodafoundation.io/)

## Join SODA Foundation

Website : [https://sodafoundation.io](https://sodafoundation.io/)

Slack  : [https://sodafoundation.io/slack/](https://sodafoundation.io/slack/)

Twitter  : [@sodafoundation](https://twitter.com/sodafoundation)

Mailinglist  : [https://lists.sodafoundation.io](https://lists.sodafoundation.io/)
